<?php
/**
 * CPT
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Saddle_Contests_Single_Sections extends Saddle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'saddle_contest_content', 'get_contest_single_sections' );
		$this->add_action( 'saddle_contest_sidebar', 'get_contest_widgets' );
	}

	public function get_contest_single_sections() {

		saddle()->horses = new Saddle_Horses_Single_Sections;

		if ( have_posts() ) {
			while ( have_posts() ) {
				the_post();
			?>

			<article class="<?php saddle_article_class(); ?>">

				<?php saddle_breadcrumbs(); ?>

				<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' ); ?>>
				<?php
					saddle()->horses->get_post_thumb();
					saddle()->horses->get_horse_header();
					saddle()->horses->get_horse_content();
				?>
				</div>

			</article>

			<?php
			}
		}
	}

	/**
	 * Get Google map
	 */
	public function get_google_map() {

		if ( ! saddle_get_settings( 'saddle_google_map_api' ) ) {
			return;
		}

		$title     = get_post_meta( get_the_ID(), 'contest_map_title', true );
		$latitude  = get_post_meta( get_the_ID(), 'contest_latitude', true );
		$longitude = get_post_meta( get_the_ID(), 'contest_longitude', true );
		$address   = get_post_meta( get_the_ID(), 'contest_address', true );
		$zoom      = get_post_meta( get_the_ID(), 'contest_map_zoom', true );
		$height    = get_post_meta( get_the_ID(), 'contest_map_height', true );

		if ( ! $latitude || ! $longitude ) {
			echo '<p>Please enter latitude and longitude.</p>';
			return;
		}

		$address = $address ? $address : 'No Address';
		$height  = $height ? $height : '250';
		$zoom    = $zoom ? $zoom : '16';

		?>
		<script>
			function initialize() {
				var latlng = new google.maps.LatLng(<?php echo $latitude; ?>, <?php echo $longitude; ?>);
				var mapOptions = {
					center: latlng,
					zoom: <?php echo $zoom; ?>,
				};
				var map = new google.maps.Map(document.getElementById("map-canvas"), mapOptions);
				marker = new google.maps.Marker({
					map: map,
					draggable: false,
					animation: google.maps.Animation.DROP,
					position: latlng
				});
				var contentString = '<?php echo '<p>' . $address . '</p>'; ?>';

				var infowindow = new google.maps.InfoWindow({
					content: contentString
				});
				google.maps.event.addListener(marker, 'click', function() {
					infowindow.open(map,marker);
				});
			}
			google.maps.event.addDomListener(window, 'load', initialize);
		</script>

		<div class="widget widget-google-map">

			<?php
			if ( $title ) {
				echo '<h3 class="widget-title">' . $title . '</h3>';
			}
			?>

			<div id="map-canvas" style="height: <?php echo $height . 'px'; ?>"></div>

		</div>

		<?php

	}

	/**
	 * Get Event date and time
	 */
	public function get_event_time() {

		$title = get_post_meta( get_the_ID(), 'contest_event_title', true );
		$date  = get_post_meta( get_the_ID(), 'contest_event_date', true );
		$time  = get_post_meta( get_the_ID(), 'contest_event_time', true );

		if ( $date ) {
			$converted_date = date( 'F j, Y', $date );
		}

		if ( ! $converted_date && ! $time ) {
			return;
		}

		?>
		<div class="widget widget-event-time">

			<?php
			if ( $title ) {
				echo '<h3 class="widget-title">' . $title . '</h3>';
			}
			?>

			<ul class="event-time-wrapper">
				<?php
				if ( $converted_date ) {
					echo '<li>';
						echo '<span class="head">' . esc_html__( 'Date:', 'saddle' ) . '</span>';
						echo '<span class="value">' . $converted_date . '</span>';
					echo '</li>';
				}
				if ( $time ) {
					echo '<li>';
						echo '<span class="head">' . esc_html__( 'Time:', 'saddle' ) . '</span>';
						echo '<span class="value">' . $time . '</span>';
					echo '</li>';
				}
				?>
			</ul>

		</div>
		<?php
	}

	/**
	 * Get Widgets
	 */
	public function get_contest_widgets() {
	?>
		<div class="cpt-sidebar">
			<?php $this->get_google_map(); ?>
			<?php $this->get_event_time(); ?>
		</div>
	<?php
	}


}

/**
 * Init
 */
new Saddle_Contests_Single_Sections();
