<?php
/**
 * Horses
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

/**
 * Contests main class.
 */
class Saddle_Contests extends Saddle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'saddle_contests_posts', 'get_contests_articles' );
	}

	/**
	 * Get posts from contests CPT
	 */
	public function get_contests_articles() {

		$arr        = [];
		$paged      = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
		$c_post_num = saddle_get_settings( 'contests_post_num' );

		$args = array(
			'post_type'           => 'contests',
			'ignore_sticky_posts' => 1,
			'post_status'         => 'publish',
			'posts_per_page'      => $c_post_num,
			'paged'               => $paged,
			'orderby'             => 'meta_value_num',
			'order'               => 'DESC',
			'meta_query'          => array( // phpcs:ignore
				array(
					'key'     => 'contest_event_date',
					'value'   => time(),
					'compare' => '>',
				),
			),
		);

		$query = new WP_Query( $args );

		$this->get_archive_details();

		echo '<div class="archive-posts-wrapper">';

		while ( $query->have_posts() ) {
			$query->the_post();

			$meta_date = get_post_meta( get_the_ID(), 'contest_event_date', true );
			if ( $meta_date ) {
				$final_date = date( 'F Y', $meta_date );
			}

			if ( ! in_array( $final_date, $arr, true ) ) {
				array_push( $arr, $final_date );
				echo '<div class="archive-date">' . $final_date . '</div>';
			}

			?>

			<article <?php post_class( 'contestPost excerpt' ); ?> id="post-<?php the_ID(); ?>">

				<?php
					$this->get_meta_info();
					$this->get_post_title();
					$this->get_read_more();
					$this->get_content();
				?>

			</article>

			<?php
		}

		saddle()->horses = new Saddle_Horses();
		saddle()->horses->get_pagination( $query );

		echo '</div>';

		wp_reset_postdata();
	}

	/**
	 * Get archive title and description
	 */
	public function get_archive_details() {
		?>
		<div class="archive-details">

			<h2 class="archive-title"><?php echo saddle_get_settings( 'contests_archive_title' ); ?></h2>
			<p class="archive-desc"><?php echo saddle_get_settings( 'contests_archive_desc' ); ?></p>

		</div>
		<?php
	}

	/**
	 * Get post title
	 */
	public function get_post_title() {
		?>
		<header>

			<h3 class="title front-view-title">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php echo the_title(); ?></a>
			</h3>

		</header>
		<?php
	}

	/**
	 * Get post extra info
	 */
	public function get_meta_info() {

		$meta_info = saddle_get_settings( 'contests_meta_info' );
		$address   = get_post_meta( get_the_ID(), 'contest_address', true );
		$date      = get_post_meta( get_the_ID(), 'contest_event_date', true );

		if ( $date ) {
			$converted_date = date( 'F j, Y', $date );
		}

		if ( ! $meta_info ) {
			return;
		}

		if ( isset( $meta_info['author'] ) || isset( $meta_info['address'] ) || isset( $meta_info['date'] ) ) {
			?>
			<div class="post-info">
				<?php
				if ( isset( $meta_info['author'] ) ) :
					echo '<span class="theauthor">' . get_the_author_posts_link() . '</span>';
				endif;
				if ( isset( $meta_info['address'] ) && $address ) :
					echo '<span class="address">' . $address . '</span>';
				endif;
				if ( isset( $meta_info['date'] ) && $converted_date ) :
					echo '<span class="thetime date">' . $converted_date . '</span>';
				endif;
				?>
			</div>
		<?php
		}

	}

	/**
	 * Get Read more
	 */
	public function get_read_more() {

		$meta_info = saddle_get_settings( 'contests_meta_info' );

		if ( isset( $meta_info['readmore'] ) ) {

			echo '<div class="readMore">';
			echo '<a href="' . get_the_permalink() . '">' . __( 'Join Event', 'saddle' ) . '<i class="fa fa-angle-right"></i></a>';
			echo '</div>';

		}

	}

	/**
	 * Get Content
	 */
	public function get_content() {
		saddle()->horses = new Saddle_Horses();
		saddle()->horses->get_post_content();
		?>
			<span class="open-content"><i class="fa fa-angle-down"></i></span>
		<?php
	}

}

/**
 * Init
 */
new Saddle_Contests();
