<?php
/**
 * CPT
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Saddle_CPT extends Saddle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'init', 'horse_custom_post_type' );
		$this->add_action( 'init', 'contests_custom_post_type' );
	}

	/*
	* Creating a function to create our Horses CPT
	*/
	function horse_custom_post_type() {

		// Set UI labels for Custom Post Type
		$labels = array(
			'name'               => _x( 'Horses', 'Post Type General Name', 'saddle' ),
			'singular_name'      => _x( 'Horse', 'Post Type Singular Name', 'saddle' ),
			'menu_name'          => __( 'Horses', 'saddle' ),
			'parent_item_colon'  => __( 'Parent Horse', 'saddle' ),
			'all_items'          => __( 'All Horses', 'saddle' ),
			'view_item'          => __( 'View Horse', 'saddle' ),
			'add_new_item'       => __( 'Add New Horse', 'saddle' ),
			'add_new'            => __( 'Add New', 'saddle' ),
			'edit_item'          => __( 'Edit Horse', 'saddle' ),
			'update_item'        => __( 'Update Horse', 'saddle' ),
			'search_items'       => __( 'Search Horse', 'saddle' ),
			'not_found'          => __( 'Not Found', 'saddle' ),
			'not_found_in_trash' => __( 'Not found in Trash', 'saddle' ),
		);

		// Set other options for Custom Post Type
		$args = array(
			'label'               => __( 'horses', 'saddle' ),
			'menu_icon'           => 'dashicons-sticky',
			'description'         => __( 'Horse posts', 'saddle' ),
			'labels'              => $labels,
			// Features this CPT supports in Post Editor
			'supports'            => array( 'title', 'editor', 'excerpt', 'author', 'thumbnail', 'comments', 'revisions', 'custom-fields' ),
			// You can associate this CPT with a taxonomy or custom taxonomy.
			'taxonomies'          => array( 'genres' ),
			/* A hierarchical CPT is like Pages and can have
			* Parent and child items. A non-hierarchical CPT
			* is like Posts.
			*/
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_in_admin_bar'   => true,
			'menu_position'       => 5,
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => false,
			'publicly_queryable'  => true,
			'capability_type'     => 'post',
			'show_in_rest'        => true,

		);

		// Registering your Custom Post Type
		register_post_type( 'horses', $args );

	}

	/*
	* Creating a function to create our Contests CPT
	*/
	function contests_custom_post_type() {

		// Set UI labels for Custom Post Type
		$labels = array(
			'name'               => _x( 'Contests', 'Post Type General Name', 'saddle' ),
			'singular_name'      => _x( 'Contest', 'Post Type Singular Name', 'saddle' ),
			'menu_name'          => __( 'Contests', 'saddle' ),
			'parent_item_colon'  => __( 'Parent Contest', 'saddle' ),
			'all_items'          => __( 'All Contests', 'saddle' ),
			'view_item'          => __( 'View Contest', 'saddle' ),
			'add_new_item'       => __( 'Add New Contest', 'saddle' ),
			'add_new'            => __( 'Add New', 'saddle' ),
			'edit_item'          => __( 'Edit Contest', 'saddle' ),
			'update_item'        => __( 'Update Contest', 'saddle' ),
			'search_items'       => __( 'Search Contest', 'saddle' ),
			'not_found'          => __( 'Not Found', 'saddle' ),
			'not_found_in_trash' => __( 'Not found in Trash', 'saddle' ),
		);

		// Set other options for Custom Post Type
		$args = array(
			'label'               => __( 'contests', 'saddle' ),
			'menu_icon'           => 'dashicons-sticky',
			'description'         => __( 'Contest news and info', 'saddle' ),
			'labels'              => $labels,
			// Features this CPT supports in Post Editor
			'supports'            => array( 'title', 'editor', 'excerpt', 'author', 'thumbnail', 'comments', 'revisions', 'custom-fields' ),
			// You can associate this CPT with a taxonomy or custom taxonomy.
			'taxonomies'          => array( 'genres' ),
			/* A hierarchical CPT is like Pages and can have
			* Parent and child items. A non-hierarchical CPT
			* is like Posts.
			*/
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_in_admin_bar'   => true,
			'menu_position'       => 5,
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => false,
			'publicly_queryable'  => true,
			'capability_type'     => 'post',
			'show_in_rest'        => true,

		);

		// Registering your Custom Post Type
		register_post_type( 'contests', $args );

	}

}

/**
 * Init
 */
new Saddle_CPT;
