<?php
/**
 * Horses
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

class Saddle_Horses extends Saddle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'saddle_horses_posts', 'get_horses_articles' );
	}

	/*
	* Get posts from horses CPT
	*/
	public function get_horses_articles() {

		$paged      = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
		$h_post_num = saddle_get_settings( 'horse_post_num' );

		$args = array(
			'post_type'           => 'horses',
			'ignore_sticky_posts' => 1,
			'posts_per_page'      => $h_post_num,
			'paged'               => $paged,
		);

		$h_query = new WP_Query( $args );

		while ( $h_query->have_posts() ) {
			$h_query->the_post();
			?>

		<article <?php post_class( 'latestPost excerpt' ); ?> id="post-<?php the_ID(); ?>">

			<?php $this->get_post_thumbnail(); ?>

			<div class="wrapper">
				<?php
					$this->get_post_title();
					$this->get_extra_info();
					$this->get_post_content();
				?>
			</div>

		</article>

		<?php
		}

		$this->get_pagination( $h_query );

		wp_reset_query();
	}

	/**
	 * Get post thumbnail
	 */
	public function get_post_thumbnail() {

		$thumb = 'saddle-horses-grid';

		?>
		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image <?php echo $thumb; ?>">
			<div class="featured-thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $thumb, array( 'title' => '' ) );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $thumb . '.png" alt="' . __( 'No Preview', 'saddle' ) . '"  class="wp-post-image" />';
				}
				?>
			</div>
		</a>
		<?php
	}

	/**
	 * Get post title
	 */
	public function get_post_title() {
	?>
	<header>

		<h2 class="title front-view-title">
			<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php echo the_title(); ?></a>
		</h2>

	</header>
	<?php
	}

	/**
	 * Get post extra info
	 */
	public function get_extra_info() {

		$all_info = get_post_meta( get_the_ID(), 'horse_info_group', true );

		if ( ! $all_info ) {
			return;
		}

		echo '<ul class="horses-info">';

		foreach ( $all_info as $info ) {
			printf(
				'<li>
					<div class="selector">%1$s</div>
					<div class="value">%2$s</div>
				</li>',
				$info['title'],
				$info['value']
			);
		}

		echo '</ul>';

	}

	/**
	 * Get post content
	 */
	public function get_post_content() {
	?>

	<div class="front-view-content">
		<?php echo get_saddle_excerpt( '25' ); ?>
	</div>

	<?php
	}

	/**
	 * Get pagination
	 */
	public function get_pagination( $query ) {

		$GLOBALS['wp_query']->max_num_pages = $query->max_num_pages;

		the_posts_pagination( array(
			'mid_size'           => 1,
			'prev_text'          => esc_html__( 'Previous', 'saddle' ),
			'next_text'          => esc_html__( 'Next', 'saddle' ),
			'screen_reader_text' => esc_html__( 'Posts navigation' ),
		) );

	}

}

/**
 * Init
 */
new Saddle_Horses;
