<?php
/**
 * Set saddle layout according to options
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Saddle_Layout extends Saddle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'saddle_before_wrapper', 'add_header' );
		$this->add_action( 'saddle_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'saddle_before_footer', 'full_related_posts' );
		$this->add_action( 'saddle_before_content', 'add_title_section' );
	}


	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = saddle_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Add Title and Breadcrumb section
	 */
	public function add_title_section() {

		if ( is_single() || is_search() || is_woocommerce_page() ) {
			return;
		}

		echo '<div class="pages-title-section">';
		echo '<div class="container">';
			echo get_page_title();
		echo '</div>';
		echo '</div>';
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		if ( ! has_post_thumbnail() ) {
			return;
		}

		$header_animation = saddle_get_post_header_effect();

		if ( ! $header_animation && saddle_get_settings( 'show_single_featured' ) ) {
			echo '<div class="single-featured-wrap">';
			the_post_thumbnail( 'saddle-featured', array( 'class' => 'single-featured-image' ) );
			echo '</div>';
		}

	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {

		if ( 'full' === saddle_get_settings( 'related_posts_position' ) ) {
			saddle_related_posts();
		}

	}

}

// Init.
new Saddle_Layout;
