<?php
/**
 * Metaboxes
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Saddle_Metaboxes extends Saddle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'cmb2_admin_init', 'saddle_horses_metaboxes' );
		$this->add_action( 'cmb2_admin_init', 'saddle_contests_metaboxes' );
	}

	/**
	 * Define the metabox configurations for horses CPT.
	 */
	function saddle_horses_metaboxes() {

		/**
	 * Initiate the metabox
	 */
		$cmb = new_cmb2_box( array(
			'id'           => 'horse_cpt_metabox',
			'title'        => esc_html__( 'Extra Info', 'saddle' ),
			'object_types' => array( 'horses' ), // Post type
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true, // Show field names on the left
		) );

		$cmb->add_field( array(
			'name'        => esc_html__( 'Widget Title', 'saddle' ),
			'id'          => 'horse_info_title',
			'type'        => 'text',
			'description' => esc_html__( 'Will be shown in widget on single page.', 'saddle' ),
			'default'     => 'More Info',
		) );

		$horse_info_group = $cmb->add_field( array(
			'id'          => 'horse_info_group',
			'type'        => 'group',
			'description' => esc_html__( 'Add more info for horses', 'saddle' ),
			'options'     => array(
				'group_title'   => esc_html__( 'Field {#}', 'saddle' ),
				'add_button'    => esc_html__( 'Add More Field', 'saddle' ),
				'remove_button' => esc_html__( 'Remove Field', 'saddle' ),
				'sortable'      => true,
			),
		) );

		// Id's for group's fields only need to be unique for the group. Prefix is not needed.
		$cmb->add_group_field( $horse_info_group, array(
			'name' => 'Field Title',
			'id'   => 'title',
			'type' => 'text',
		) );
		$cmb->add_group_field( $horse_info_group, array(
			'name' => 'Field Value',
			'id'   => 'value',
			'type' => 'text',
		) );

	}

	/**
	 * Define the metabox configurations for Contests CPT.
	 */
	function saddle_contests_metaboxes() {

		/**
	 * Initiate the metabox
	 * Google map
	 */
		$cmb = new_cmb2_box( array(
			'id'           => 'contests_cpt_map_metabox',
			'title'        => esc_html__( 'Google Map Settings', 'saddle' ),
			'desc'         => esc_html__( 'Add more info for horses', 'saddle' ),
			'object_types' => array( 'contests' ), // Post type
			'context'      => 'side',
			'priority'     => 'high',
			'show_names'   => true, // Show field names on the left
		) );
		$cmb->add_field( array(
			'id'   => 'contests_cpt_map_desc',
			// translators: Using strong tag in description.
			'desc' => sprintf( __( 'You need to enter Google map api in %s', 'saddle' ), '<strong><em>Theme Options > Custom Posts > Contests<em><strong>' ),
			'type' => 'title',
		) );

		$cmb->add_field( array(
			'name'    => esc_html__( 'Widget Title', 'saddle' ),
			'id'      => 'contest_map_title',
			'type'    => 'text',
			'default' => 'Event Location',
		) );

		$cmb->add_field( array(
			'name' => esc_html__( 'Latitude', 'saddle' ),
			'id'   => 'contest_latitude',
			'type' => 'text',
		) );
		$cmb->add_field( array(
			'name' => esc_html__( 'Longitude', 'saddle' ),
			'id'   => 'contest_longitude',
			'type' => 'text',
		) );
		$cmb->add_field( array(
			'name' => esc_html__( 'Address to show', 'saddle' ),
			'id'   => 'contest_address',
			'type' => 'textarea_small',
		) );
		$cmb->add_field( array(
			'name'       => esc_html__( 'Map Zoom', 'saddle' ),
			'desc'       => 'default value of map zoom',
			'id'         => 'contest_map_zoom',
			'type'       => 'text_small',
			'default'    => '16',
			'attributes' => array(
				'type' => 'number',
			),
		) );
		$cmb->add_field( array(
			'name'       => esc_html__( 'Map Height', 'saddle' ),
			'desc'       => 'default height of map in px',
			'id'         => 'contest_map_height',
			'type'       => 'text_small',
			'default'    => '250',
			'attributes' => array(
				'type' => 'number',
			),
		) );

		/**
	 * Event Time grounp
	 */
		$cmb = new_cmb2_box( array(
			'id'           => 'contests_cpt_time_metabox',
			'title'        => esc_html__( 'Event Time', 'saddle' ),
			'object_types' => array( 'contests' ), // Post type
			'context'      => 'side',
			'priority'     => 'high',
			'show_names'   => true, // Show field names on the left
		) );

		$cmb->add_field( array(
			'name'    => esc_html__( 'Widget Title', 'saddle' ),
			'id'      => 'contest_event_title',
			'type'    => 'text',
			'default' => 'Event Timing',
		) );

		$cmb->add_field( array(
			'name' => esc_html__( 'Event Date', 'saddle' ),
			'id'   => 'contest_event_date',
			'type' => 'text_date_timestamp',
		) );
		$cmb->add_field( array(
			'name' => esc_html__( 'Event Time', 'saddle' ),
			'id'   => 'contest_event_time',
			'type' => 'text_time',
		) );

	}

}

/**
 * Init
 */
new Saddle_Metaboxes();
