<?php
/**
 * HomePage Pagination
 *
 * @package Saddle
 */

$menus['blog-pagination'] = array(
	'icon'  => 'fa-ellipsis-h',
	'title' => esc_html__( 'Pagination', 'saddle' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'saddle' ),
);

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	),
);

// Dependency check the load more button.
$loadmore_button_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	),
);

$sections['blog-pagination'] = array(

	array(
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'saddle' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'saddle' ),
		'options'  => array(
			'0' => esc_html__( 'Default (Next / Previous)', 'saddle' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'saddle' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'saddle' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'saddle' ),
		),
		'std'      => '2',
	),

	array(
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'saddle' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'saddle' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'saddle' ),
			'center' => esc_html__( 'Center', 'saddle' ),
			'right'  => esc_html__( 'Right', 'saddle' ),
		),
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	),

	array(
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'saddle' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'saddle' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'saddle' ),
			'center' => esc_html__( 'Center', 'saddle' ),
			'right'  => esc_html__( 'Right', 'saddle' ),
			'full'   => esc_html__( 'Full Width', 'saddle' ),
		),
		'std'        => 'full',
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'saddle' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'saddle' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background hover color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'saddle' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background hover color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select load more background hover color.', 'saddle' ),
		'std'        => '#504b46',
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'saddle' ),
		'std'        => '#504b46',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'saddle' ),
		'std'        => '#504b46',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'saddle' ),
		'std'        => '#d5ba9f',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'saddle' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'saddle' ),
		'std'        => '#d5ba9f',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'       => 'mts_pagenavigation_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Pagination Margin', 'saddle' ),
		'sub_desc' => esc_html__( 'Update pagination margin from here.', 'saddle' ),
		'std'      => array(
			'top'    => '0',
			'right'  => saddle_px_to_rem( '35px' ),
			'bottom' => '0',
			'left'   => '0',
		),
	),
	array(
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'saddle' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'saddle' ),
		'std'        => array(
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'saddle' ),
		'sub_desc'   => esc_html__( 'Update padding for load more button from here.', 'saddle' ),
		'std'        => array(
			'top'    => saddle_px_to_rem( '25px' ),
			'right'  => saddle_px_to_rem( '30px' ),
			'bottom' => saddle_px_to_rem( '25px' ),
			'left'   => saddle_px_to_rem( '30px' ),
		),
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'       => 'mts_pagenavigation_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Pagination border radius', 'saddle' ),
		'sub_desc' => esc_html__( 'Update pagination border radius in px.', 'saddle' ),
		'std'      => '0',
		'args'     => array( 'type' => 'number' ),
	),
	array(
		'id'       => 'pagenavigation_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'saddle' ),
		'sub_desc' => esc_html__( 'Select border', 'saddle' ),
	),
	array(
		'id'    => 'pagination_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Pagination', 'saddle' ),
		'color' => false,
		'std'   => array(
			'preview-text'   => 'Pagination',
			'preview-color'  => 'light',
			'font-family'    => 'Roboto',
			'font-weight'    => '700',
			'font-size'      => '20px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.pagination, #load-posts a',
		),
	),

);
