<?php
/**
 * HomePage Posts
 *
 * @package Saddle
 */

$features = saddle_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'saddle' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Saddle
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'saddle' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'saddle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'saddle' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'saddle' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'saddle' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'saddle' ),
				'center' => esc_html__( 'Center', 'saddle' ),
				'right'  => esc_html__( 'Right', 'saddle' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'saddle' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'saddle' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'saddle' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'saddle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => saddle_px_to_rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'saddle' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'saddle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'saddle' ),
			'sub_desc'   => esc_html__( 'Select border', 'saddle' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'saddle' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Playfair Display',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'color'         => '#504b46',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'saddle' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'saddle' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'saddle' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'show_readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show ReadMore', 'saddle' ),
			'sub_desc' => esc_html__( 'Show/Hide readmore button from this option.', 'saddle' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'saddle' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'margin-top'     => saddle_px_to_rem( '26px' ),
				'color'          => '#d5ba9f',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 5px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .readMore a',
			),
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'saddle' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'saddle' ),
			'sub_desc' => esc_html__( 'Select border', 'saddle' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'saddle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'saddle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => saddle_px_to_rem( '79px' ),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'saddle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'saddle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'saddle' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Playfair Display',
				'font-weight'    => '700',
				'font-size'      => '38px',
				'line-height'    => '1.26',
				'margin-top'     => saddle_px_to_rem( '45px' ),
				'color'          => '#504b46',
				'additional-css' => 'letter-spacing: -0.19px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'saddle' ),
			'std'   => array(
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '300',
				'font-size'      => '16px',
				'line-height'    => '1.625',
				'margin-top'     => saddle_px_to_rem( '20px' ),
				'additional-css' => 'letter-spacing: 0.256px;',
				'color'          => '#504b46',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout Grid Settings
		 *
		 * @package Saddle
		 */

		// Section Title.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'saddle' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'saddle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'saddle' ),
			'std'      => '0',
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'saddle' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'saddle' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'saddle' ),
				'center' => esc_html__( 'Center', 'saddle' ),
				'right'  => esc_html__( 'Right', 'saddle' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'saddle' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'saddle' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'saddle' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'saddle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => saddle_px_to_rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'saddle' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'saddle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'saddle' ),
			'sub_desc'   => esc_html__( 'Select border', 'saddle' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'saddle' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Playfair Display',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'color'         => '#504b46',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'saddle' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'saddle' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'saddle' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'date' => array(
						'label'     => esc_html__( 'Date', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
				'disabled' => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'author'   => array(
						'label'     => __( 'Author Name', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'date' => array(
						'label'     => esc_html__( 'Date', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
				'disabled' => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'author'   => array(
						'label'     => __( 'Author Name', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'saddle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'saddle' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'saddle' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'margin-top'     => saddle_px_to_rem( '15px' ),
				'color'          => '#d5ba9f',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 5px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'saddle' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'saddle' ),
			'sub_desc' => esc_html__( 'Select border', 'saddle' ),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'saddle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'saddle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => saddle_px_to_rem( '39px' ),
			),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'saddle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'saddle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'saddle' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Playfair Display',
				'font-weight'    => '700',
				'font-size'      => '24px',
				'line-height'    => '1.26',
				'margin-top'     => saddle_px_to_rem( '20px' ),
				'color'          => '#504b46',
				'additional-css' => 'letter-spacing: -0.12px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Saddle
		 */
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'saddle' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'saddle' ),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'saddle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'saddle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'saddle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'saddle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
