<?php
/**
 * Page Titles and Breadcrumbs
 *
 * @package Saddle
 */

$menus['blog-titles'] = array(
	'icon'  => 'fa-bars',
	'title' => esc_html__( 'Title & Breadcrumb', 'saddle' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your titles and breadcrumbs.', 'saddle' ),
);

// Dependency check.
$pages_title = array(
	'relation' => 'and',
	array(
		'field'      => 'show_pages_title',
		'value'      => '1',
		'comparison' => '==',
	),
);

$sections['blog-titles'] = array(

	array(
		'id'       => 'show_pages_title',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Pages Title', 'saddle' ),
		'sub_desc' => esc_html__( 'Enable/Disable the Pages Title form here.', 'saddle' ),
		'std'      => '1',
	),

	array(
		'id'         => 'breadcrumbs_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Breadcrumbs Settings', 'saddle' ),
		'dependency' => $pages_title,
	),

	array(
		'id'         => 'show_breadcrumb',
		'type'       => 'switch',
		'title'      => esc_html__( 'Breadcrumbs', 'saddle' ),
		'sub_desc'   => esc_html__( 'Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'saddle' ),
		'std'        => '1',
		'dependency' => $pages_title,
	),

	array(
		'id'         => 'breadcrumb_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Breadcrumbs Font', 'saddle' ),
		'std'        => array(
			'preview-text'   => 'Breadcrumbs',
			'preview-color'  => 'light',
			'font-family'    => 'Roboto',
			'font-weight'    => '500',
			'font-size'      => '15px',
			'color'          => '#d5ba9f',
			'additional-css' => 'letter-spacing: 2.505px;',
			'css-selectors'  => '.breadcrumb, .rank-math-breadcrumb',
		),
		'dependency' => array(
			'relation' => 'and',
			array(
				'field'      => 'show_breadcrumb',
				'value'      => '1',
				'comparison' => '==',
			),
			array(
				'field'      => 'show_pages_title',
				'value'      => '1',
				'comparison' => '==',
			),
		),
	),

	array(
		'id'         => 'pages_titles_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Page Titles Settings', 'saddle' ),
		'dependency' => $pages_title,
	),

	array(
		'id'         => 'blog_small_title',
		'type'       => 'text',
		'title'      => esc_html__( 'Blog Page Small Title', 'saddle' ),
		'sub_desc'   => esc_html__( 'Enter blog page small title text it will be shown on top of Blog Posts.', 'saddle' ),
		'std'        => 'Stories from',
		'dependency' => $pages_title,
	),
	array(
		'id'         => 'blog_title',
		'type'       => 'text',
		'title'      => esc_html__( 'Blog Page Title', 'saddle' ),
		'sub_desc'   => esc_html__( 'Enter blog page title text it will be shown on top of Blog Posts.', 'saddle' ),
		'std'        => 'Our Blog',
		'dependency' => $pages_title,
	),

	array(
		'id'         => 'pages_title_background',
		'type'       => 'background',
		'title'      => esc_html__( 'Pages Title Background', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'saddle' ),
		'options'    => array(
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
			'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
			'position'      => array(),       // false to disable, array of options to override default ( optional ).
			'size'          => array(),       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
		),
		'std'        => array(
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => array(
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			),
			'parallax'      => '0',
		),
		'dependency' => $pages_title,
	),

	array(
		'id'         => 'pages_title_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Margin', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set Titles section margin from here.', 'saddle' ),
		'std'        => array(
			'top'    => saddle_px_to_rem( '99px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $pages_title,
	),
	array(
		'id'         => 'pages_title_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Padding', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set Titles section padding from here.', 'saddle' ),
		'std'        => array(
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $pages_title,
	),

	array(
		'id'         => 'pages_small_title_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Page Title Font', 'saddle' ),
		'std'        => array(
			'preview-text'   => 'Page Small Title',
			'preview-color'  => 'light',
			'font-family'    => 'Playfair Display',
			'font-weight'    => '700',
			'font-size'      => '14px',
			'line-height'    => '1',
			'color'          => '#d5ba9f',
			'additional-css' => 'text-transform: uppercase; letter-spacing: 5px;',
			'css-selectors'  => '.pages-title-section .small-title',
		),
		'dependency' => $pages_title,
	),
	array(
		'id'         => 'pages_title_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Page Title Font', 'saddle' ),
		'std'        => array(
			'preview-text'   => 'Page Title',
			'preview-color'  => 'light',
			'font-family'    => 'Playfair Display',
			'font-weight'    => '700',
			'color'          => '#504b46',
			'font-size'      => '28px',
			'additional-css' => 'text-transform: uppercase; letter-spacing: 5.824px;',
			'css-selectors'  => '.pages-title-section .title',
		),
		'dependency' => $pages_title,
	),

);
