<?php
/**
 * Header Tab
 *
 * @package Saddle
 */

$menus['header'] = array(
	'icon'  => 'fa-header',
	'title' => esc_html__( 'Header', 'saddle' ),
);

$menus['header']['child']['header-general'] = array(
	'title' => esc_html__( 'General', 'saddle' ),
	'desc'  => esc_html__( 'From here, you can control the elements of header section.', 'saddle' ),
);

$default_header_only = array(
	'relation' => 'and',
	array(
		'field'      => 'header_styles',
		'value'      => 'header-default',
		'comparison' => '==',
	),
);
$header_layout2_only = array(
	'relation' => 'and',
	array(
		'field'      => 'header_styles',
		'value'      => 'header-layout2',
		'comparison' => '==',
	),
);

$sections['header-general'] = array(

	array(
		'id'       => 'header_styles',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Header Styling', 'saddle' ),
		'sub_desc' => wp_kses( __( 'Choose the <strong>Header design</strong> for your site.', 'saddle' ), array( 'strong' => '' ) ),
		'options'  => array(
			'header-default' => array( 'img' => $uri . 'headers/header-default.jpg' ),
			'header-layout2' => array( 'img' => $uri . 'headers/header-layout2.jpg' ),
		),
		'std'      => 'header-default',
	),

	array(
		'id'    => 'header_general_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Header General Settings', 'saddle' ),
	),

	array(
		'id'       => 'sticky_nav',
		'type'     => 'switch',
		'title'    => esc_html__( 'Floating Navigation Menu', 'saddle' ),
		// translators: Floating Navigation Menu with strong tag.
		'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'saddle' ), '<strong>' . esc_html__( 'Floating Navigation Menu', 'saddle' ) . '</strong>' ),
		'std'      => '0',
	),

	array(
		'id'         => 'sticky_responsive_nav',
		'type'       => 'switch',
		'title'      => esc_html__( 'Floating Navigation Responsive', 'saddle' ),
		'sub_desc'   => wp_kses( __( 'Use this button to Show or Hide the <strong>Floating Navigation Menu</strong> on Responsive screen.', 'saddle' ), array( 'strong' => '' ) ),
		'std'        => '0',
		'dependency' => array(
			'relation' => 'and',
			array(
				'field'      => 'sticky_nav',
				'value'      => '1',
				'comparison' => '==',
			),
		),
	),

	array(
		'id'         => 'header_height',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Max Height', 'saddle' ),
		'sub_desc'   => esc_html__( 'Enter maximum height in px for header. Leave blank for auto.', 'saddle' ),
		'args'       => array( 'type' => 'number' ),
		'std'        => '160',
		'dependency' => $default_header_only,
	),

	array(
		'id'       => 'header_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Margin', 'saddle' ),
		'sub_desc' => esc_html__( 'Set header margin from here.', 'saddle' ),
		'left'     => false,
		'right'    => false,
		'std'      => array(
			'top'    => '0',
			'bottom' => '0',
		),
	),
	array(
		'id'       => 'header_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Padding', 'saddle' ),
		'sub_desc' => esc_html__( 'Set header padding from here.', 'saddle' ),
		'left'     => false,
		'right'    => false,
		'std'      => array(
			'top'    => saddle_px_to_rem( '48px' ),
			'bottom' => '0',
		),
	),

	array(
		'id'       => 'header_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'saddle' ),
		'sub_desc' => esc_html__( 'Select border.', 'saddle' ),
	),

	array(
		'id'         => 'header_background',
		'type'       => 'background',
		'title'      => esc_html__( 'Header Background', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'saddle' ),
		'options'    => array(
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
			'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
			'position'      => array(),       // false to disable, array of options to override default ( optional ).
			'size'          => array(),       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
		),
		'std'        => array(
			'color'         => '',
			'use'           => 'upload',
			'image_pattern' => 'nobg',
			'image_upload'  => get_template_directory_uri() . '/images/header-bg.jpg',
			'repeat'        => 'no-repeat',
			'attachment'    => 'scroll',
			'position'      => 'center bottom',
			'size'          => 'cover',
			'gradient'      => array(
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			),
			'parallax'      => '0',
		),
	),

	array(
		'id'         => 'header_background_position',
		'type'       => 'select',
		'title'      => esc_html__( 'Header Background Position', 'saddle' ),
		'sub_desc'   => esc_html__( 'Use this button to change the Header Background position, This will effect all pages except HomePage.', 'saddle' ),
		'options'    => array(
			''              => esc_html__( 'Default', 'saddle' ),
			'left top'      => esc_html__( 'Left Top', 'saddle' ),
			'left center'   => esc_html__( 'Left center', 'saddle' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'saddle' ),
			'center top'    => esc_html__( 'Center Top', 'saddle' ),
			'center center' => esc_html__( 'Center Center', 'saddle' ),
			'center bottom' => esc_html__( 'Center Bottom', 'saddle' ),
			'right top'     => esc_html__( 'Right Top', 'saddle' ),
			'right center'  => esc_html__( 'Right center', 'saddle' ),
			'right bottom'  => esc_html__( 'Right Bottom', 'saddle' ),
		),
		'std'        => 'center center',
	),

	array(
		'id'       => 'hide_logo',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Logo', 'saddle' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Logo</strong> completely.', 'saddle' ), array( 'strong' => '' ) ),
		'std'      => '1',
	),

	array(
		'id'         => 'header_social_icons',
		'title'      => esc_html__( 'Header Social Icons', 'saddle' ),
		'sub_desc'   => esc_html__( 'Add Social Media icons in header.', 'saddle' ),
		'type'       => 'group',
		'groupname'  => esc_html__( 'Header Icon', 'saddle' ), // Group name.
		'subfields'  => array(
			array(
				'id'    => 'header_icon_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'saddle' ),
			),
			array(
				'id'    => 'header_icon',
				'type'  => 'icon_select',
				'title' => esc_html__( 'Icon', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_link',
				'type'  => 'text',
				'title' => esc_html__( 'URL', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background color', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_hover_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background hover color', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon color', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_hover_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon hover color', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_margin',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Margin', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_padding',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Padding', 'saddle' ),
			),
			array(
				'id'    => 'header_icon_border_radius',
				'type'  => 'text',
				'class' => 'small-text',
				'title' => esc_html__( 'Header icon border radius', 'saddle' ),
				'args'  => array( 'type' => 'number' ),
			),
		),
		'std'        => array(
			'facebook'  => array(
				'group_title'               => 'Facebook',
				'group_sort'                => '1',
				'header_icon_title'         => 'Facebook',
				'header_icon'               => 'facebook-official',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#ffffff',
				'header_icon_hover_color'   => saddle_get_settings( 'secondary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'youtube'   => array(
				'group_title'               => 'Youtube',
				'group_sort'                => '2',
				'header_icon_title'         => 'Youtube',
				'header_icon'               => 'youtube-play',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#ffffff',
				'header_icon_hover_color'   => saddle_get_settings( 'secondary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'twitter'   => array(
				'group_title'               => 'Twitter',
				'group_sort'                => '3',
				'header_icon_title'         => 'Twitter',
				'header_icon'               => 'twitter',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#ffffff',
				'header_icon_hover_color'   => saddle_get_settings( 'secondary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'pinterest' => array(
				'group_title'               => 'Pinterest',
				'group_sort'                => '4',
				'header_icon_title'         => 'Pinterest',
				'header_icon'               => 'pinterest',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#ffffff',
				'header_icon_hover_color'   => saddle_get_settings( 'secondary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'instagram' => array(
				'group_title'               => 'Instagram',
				'group_sort'                => '5',
				'header_icon_title'         => 'Instagram',
				'header_icon'               => 'instagram',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#ffffff',
				'header_icon_hover_color'   => saddle_get_settings( 'secondary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),

		),
		'dependency' => $header_layout2_only,
	),

	// Nav Settings.
	array(
		'id'    => 'header_nav_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Nav Settings', 'saddle' ),
	),
	array(
		'id'       => 'nav_background',
		'type'     => 'color',
		'title'    => esc_html__( 'Nav Background', 'saddle' ),
		'sub_desc' => esc_html__( 'Select nav background color from here.', 'saddle' ),
		'std'      => '#201e1e',
	),
	array(
		'id'       => 'main_nav_dropdown_bg',
		'type'     => 'color',
		'title'    => esc_html__( 'Dropdown Background Color', 'saddle' ),
		'sub_desc' => esc_html__( 'Select dropdown background color for navigation from here.', 'saddle' ),
		'std'      => '#ffffff',
	),
	array(
		'id'       => 'main_navigation_dropdown_color',
		'type'     => 'color',
		'title'    => esc_html__( 'Dropdown Text Color', 'saddle' ),
		'sub_desc' => esc_html__( 'Select dropdown text color for navigation from here.', 'saddle' ),
		'std'      => '#504b46',
	),
	array(
		'id'       => 'main_navigation_dropdown_hover_color',
		'type'     => 'color',
		'title'    => esc_html__( 'Dropdown Text Hover Color', 'saddle' ),
		'sub_desc' => esc_html__( 'Select dropdown text hover color for navigation from here.', 'saddle' ),
		'std'      => '#d5ba9f',
	),

	// Header layout Default
	array(
		'id'         => 'header_nav_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Margin', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set nav margin from here.', 'saddle' ),
		'std'        => array(
			'top'    => saddle_px_to_rem( '41px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $default_header_only,
	),
	array(
		'id'         => 'header_nav_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Padding', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set nav padding from here.', 'saddle' ),
		'std'        => array(
			'top'    => '0',
			'right'  => saddle_px_to_rem( '25px' ),
			'bottom' => '0',
			'left'   => saddle_px_to_rem( '25px' ),
		),
		'dependency' => $default_header_only,
	),

	// Header layout 2
	array(
		'id'         => 'header2_nav_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Margin', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set nav margin from here.', 'saddle' ),
		'std'        => array(
			'top'    => saddle_px_to_rem( '55px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $header_layout2_only,
	),
	array(
		'id'         => 'header2_nav_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Padding', 'saddle' ),
		'sub_desc'   => esc_html__( 'Set nav padding from here.', 'saddle' ),
		'std'        => array(
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $header_layout2_only,
	),

);
